FlareStatusType enum

The semantic classification for FlareStatus chips.

Inheritance
Available extensions

Values

success → const FlareStatusType

Represents a successful completion or positive state.

error → const FlareStatusType

Represents a failure or critical condition.

warning → const FlareStatusType

Represents a potential issue or cautionary state.

info → const FlareStatusType

Represents standard information or informative state.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlareStatusType>
A constant List of the values in this enum, in order of their declaration.